@@ -1,9 +1,7 @@
 package MooseX::AttributeHelpers::Bool;
 use Moose;
 
-our $VERSION   = '0.19';
-$VERSION = eval $VERSION;
-our $AUTHORITY = 'cpan:STEVAN';
+our $VERSION = '0.24';
 
 extends 'Moose::Meta::Attribute';
 with 'MooseX::AttributeHelpers::Trait::Bool';
