@@ -2,9 +2,7 @@
 package MooseX::AttributeHelpers::Trait::Collection;
 use Moose::Role;
 
-our $VERSION   = '0.19';
-$VERSION = eval $VERSION;
-our $AUTHORITY = 'cpan:STEVAN';
+our $VERSION = '0.24';
 
 with 'MooseX::AttributeHelpers::Trait::Base';
 
